#!/usr/bin/env python3

import argparse
import re
import sys


def rl(convert='', a=False, f=sys.stdin):
    line = f.readline().split()
    for i, c in enumerate(convert):
        if c == 'i':
            line[i] = int(line[i])
        elif c == 's':
            pass
        elif c == 'f':
            line[i] = float(line[i])
    if not a and len(line) == 1:
        return line[0]
    return line


def is_subseq(x, y):
    it = iter(y)
    return all(any(c == ch for c in it) for ch in x)


def check(s, u):
    try:
        # check subsequence
        assert is_subseq(u, s), 'Wrong answer: Expression is not a subsequence of the input expression.'
        # check **
        assert '**' not in u, 'Wrong answer: This is not a valid expression.'
        # check zeros
        for m in re.finditer(r'[0-9]+', u):
            m = m.group(0)
            assert (m == '0' or not m.startswith('0')), 'Wrong answer: Expression has unnecessary leading zeros.'
        # check eval
        try:
            assert str(eval(u)) == str(int(''.join(filter(lambda x: '0' <= x <= '9', s))))
        except AssertionError:
            raise Exception('Wrong answer.')
        except Exception:
            raise Exception('Wrong answer: This is not a valid expression.')
    except Exception as e:
        return False, e
    return True, None


def main(args):
    try:
        inp = open(args.input, 'r')
        u_out = open(args.user_output, 'r')
        u_out_list = u_out.read().split()
        tc = rl('i', f=inp)
        if len(u_out_list) != tc: raise Exception('Wrong answer: Found %d expressions, not %d' % (len(u_out_list), tc))
        for _ in range(tc):
            rl(f=inp)  # empty line
            s = rl('s', f=inp)
            u = u_out_list[_]
            s, e = check(s, u)
            if not s:
                raise e
    except Exception as error_message:
        error_message = str(error_message)
        if error_message[:12] != 'Wrong answer': error_message = 'Wrong answer: ' + error_message
        print(error_message)
        exit(1)
    print("OK")


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Verify user output for problem G in IPSC 2016')
    parser.add_argument('input')
    parser.add_argument('user_output')
    main(parser.parse_args())
